@@ -1,7 +1,6 @@
 import { awscdk } from 'projen';
 import { UpgradeDependenciesSchedule } from 'projen/lib/javascript';
 
-const excludes = ['.idea/', 'cdk.out/', 'cdk.context.json', 'yarn-error.log'];
 const project = new awscdk.AwsCdkConstructLibrary({
   author: 'Yohta Kimura',
   authorAddress: 'kitakita7617@gmail.com',
@@ -29,21 +28,30 @@ const project = new awscdk.AwsCdkConstructLibrary({
     distName: 'low-cost-ecs',
     module: 'low_cost_ecs',
   },
-
-  npmignore: excludes,
-  gitignore: excludes,
   autoApproveOptions: {
     allowedUsernames: ['rajyan'],
   },
   depsUpgradeOptions: {
     workflowOptions: {
       schedule: UpgradeDependenciesSchedule.WEEKLY,
+      labels: ['auto-approve'],
     },
   },
   projenrcTs: true,
 });
 
+const excludes = ['.idea/', 'cdk.out/', 'cdk.context.json', 'yarn-error.log'];
+project.npmignore?.exclude(...excludes);
+project.gitignore.exclude(...excludes);
+
 project.tsconfigDev.addInclude('examples/**/*.ts');
+
+// Remove '--updateSnapshot' from test task
+// Work around until https://github.com/projen/projen/issues/1144 is solved
+const testTask = project.tasks.tryFind('test');
+const newTestCommand = testTask!.steps[0]!.exec!.replace(' --updateSnapshot', '');
+testTask!.reset(newTestCommand);
+
 // workaround until fixed https://youtrack.jetbrains.com/issue/WEB-57089/ESLint823-TypeError-thislibOptionsparse-is-not-a-function
 project.addDevDeps('eslint@8.22.0');
 
